@@ -1,19 +1,7 @@
 /*  This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2016 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2016 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "keyselectioncombo.h"
@@ -163,7 +151,7 @@ public:
 
             return sourceModel()->index(row, index.column());
         } else {
-            return QModelIndex();
+            return {};
         }
     }
 
@@ -176,7 +164,7 @@ public:
     QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
     {
         if (row < 0 || row >= rowCount()) {
-            return QModelIndex();
+            return {};
         }
         if (row < mFrontItems.count()) {
             return createIndex(row, column, mFrontItems[row]);
@@ -197,7 +185,7 @@ public:
     QModelIndex parent(const QModelIndex &) const override
     {
         // Flat list
-        return QModelIndex();
+        return {};
     }
 
     QVariant data(const QModelIndex &index, int role) const override
@@ -208,7 +196,7 @@ public:
 
         if (isCustomItem(index.row())) {
             Q_ASSERT(!mFrontItems.isEmpty() || !mBackItems.isEmpty());
-            CustomItem *ci = static_cast<CustomItem*>(index.internalPointer());
+            auto *ci = static_cast<CustomItem*>(index.internalPointer());
             switch (role) {
             case Qt::DisplayRole:
                 return ci->text;
